-------------------------------------------------------------------------------------------------------------------------------------------------------------------
-- 	Version 1.1
-- 	Published 09/29/2008
-- 	Idea by Lee Johnson - www.jtwo.com
-- 	Code by Anton Vasilescu - anton@75ive.com | www.75ive.com

-- 	What does it do?
-- 		Allows you to select a Box object and a Pin object and creates instances of the Pin which use an
-- 		Attachment Controller to stay connected to the box object
-- 	How to use it?
--		Goto MaxScript -> Run Script, and choose the Pinbox Creator 1.1.ms
-- 		Press the "Pick Box Object" button to select your base object
-- 		Press the "Pick Pin Object" button to select the pin object
-- 		Press the "Make Pinbox" button to create the pin box
-------------------------------------------------------------------------------------------------------------------------------------------------------------------

rollout rlt_Pinbox "Pin to Box Attachment"		--create a dialog box for the script
	(
		group "Box Object"
		(
			pickButton btn_pickBox "Pick Box Object" width:200 height:30		--pickbuton to select the box object from the scene
			label lbl_boxObjName "--------------------------"		--label to display the name of the box object
		)
		group "Pin Object"
		(
			pickButton btn_pickPin "Pick Pin Object" width:200 height:30		--pickbuton to select the pin object from the scene
			label lbl_pinObjName "--------------------------"		--label to display the name of the pin object
		)
		button btn_makePinbox "Make Pinbox" width:212 height:35		--button to run the script
		
		local theBox = undefined		--define empty variable for the Box object for later assignment
		local thePin = undefined		--define empty variable for the Pin object for later assignment
		
		function fn_makePinBox tB tP =		--the function that assigns the controller and sets up all the parameters for it
		(	
			if classof tB != Editable_mesh and classof tB != Editable_Poly and classof tB != PolyMeshObject then		-- if the box object is not editable mesh and editable poly
			(
				addmodifier tB (Edit_Poly())		--add an editable poly modifier on top
			)
			for i = 1 to (tB.faces.count/2) do		--loop through all the polygons of the base object and divide by two because there are twice as many poly's as there will be pins
			(
				theController = Attachment()		--create the Attachment Controller
				theWirecolor = tP.wirecolor		--save the wirecolor of the initial pin object
				if i != 1 then 
				(
					tP = instance tP		--use the Pin object first time but every time after, create an instance of it
					tP.wirecolor = theWirecolor		--assign the same wirecolor to all the instance objects
				)
				tP.position.controller = theController		--assign the Attachment Controller to the Pin object
				theController.node = tB		--tell the Assignment Controller that the controller object is the Box
				theController.align = false		--keeps the objects from aligning to the normal of the face
				addNewKey theController 0f		--add a key to the controller at frame 0
				theKey = attachCtrl.getKey theController 1		--assign the value of the key to a variable for further use
				theKey.face = i*2-1		--assigns the face to be used by the pin ( we multiply by 2 as there are 2 faces in a polygon and subtract 1 to get back to polygon #1)
				theKey.coord = [0.5,0]		--sets the barycentric coordinate for the face
			)
		)

		on btn_pickBox picked obj do		--if the user picked the box object, then
		(
			if obj != undefined then		--see if the user did not cancel the picking...
			(
				lbl_boxObjName.text = obj.name		--if he did not, display the name of the picked object in the box label
				theBox = obj		--assign the selected object to the predefined variable
			)
		)
		
		on btn_pickPin picked obj do		--if the user picked the item object, then
		(
			if obj != undefined then		--see if the user did not cancel the picking...
			(
				lbl_pinObjName.text = obj.name		--if he did not, display the name of the picked object in the pin label
				thePin = obj		--assign the selected object to the predefined variable
			)
		)
		
		on btn_makePinbox pressed do fn_makePinBox theBox thePin		--runs the function to create the pin box
	)
	createdialog rlt_Pinbox 220 200		--create the pin box dilog